@@ -917,8 +917,8 @@
       ((enum)
        (let* ((info (ctype-info ct))
               (mtype (cenum-mtype info))
-              (numf (cenum-numf info)))
-         (numf (mtype-bv-ref mtype bv ix))))
+              (symf (cenum-symf info)))
+         (symf (mtype-bv-ref mtype bv ix))))
       ((array struct union) (%make-cdata bv ix ct))
       ((function)
        (let* ((ti (ctype-info ct))
